@@ -9,7 +9,7 @@ import (
 	"github.com/muesli/termenv"
 )
 
-func code(input string) (string, error) {
+func code(input, language string) (string, error) {
 	renderer, err := glamour.NewTermRenderer(
 		glamour.WithAutoStyle(),
 		glamour.WithWordWrap(0),
@@ -17,7 +17,7 @@ func code(input string) (string, error) {
 	if err != nil {
 		return "", fmt.Errorf("unable to create renderer: %w", err)
 	}
-	output, err := renderer.Render(fmt.Sprintf("```\n%s\n```", input))
+	output, err := renderer.Render(fmt.Sprintf("```%s\n%s\n```", language, input))
 	if err != nil {
 		return "", fmt.Errorf("unable to render: %w", err)
 	}
